@@ -60,7 +60,7 @@ function _onMenuStateChanged(menu, isOpen) {
 function _getAppStableSequence(app) {
     return app.get_windows().reduce(function(prev, cur) {
         return Math.min(prev, cur.get_stable_sequence());
-    }, 0);
+    }, Infinity);
 }
 
 
